@@ -39,10 +39,7 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock/demo
 
 static inline CairoDockModuleInstance *_get_module_instance_from_dbus_applet (dbusApplet *pDbusApplet)
 {
-	CairoDockModule *pModule = cairo_dock_find_module_from_name (pDbusApplet->cModuleName);
-	g_return_val_if_fail (pModule != NULL && pModule->pInstancesList != NULL, NULL);
-	
-	return pModule->pInstancesList->data;
+	return pDbusApplet->pModuleInstance;
 }
 
 static inline gboolean _get_icon_and_container_from_id (dbusApplet *pDbusApplet, const gchar *cIconID, Icon **pIcon, CairoContainer **pContainer)
@@ -86,6 +83,7 @@ static gboolean _applet_set_label (dbusApplet *pDbusApplet, const gchar *cLabel,
 		return FALSE;
 	
 	cairo_dock_set_icon_name (cLabel, pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon, pContainer);  /// needs a function to redraw the label...
 	return TRUE;
 }
 
@@ -104,6 +102,26 @@ static gboolean _applet_set_icon (dbusApplet *pDbusApplet, const gchar *cImage,
 	return TRUE;
 }
 
+static gboolean _applet_set_icon_with_default (dbusApplet *pDbusApplet, const gchar **cImages, const gchar *cIconID, GError **error)
+{
+	Icon *pIcon;
+	CairoContainer *pContainer;
+	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
+		return FALSE;
+	
+	g_return_val_if_fail (pIcon->pIconBuffer != NULL, FALSE);
+	cairo_t *pIconContext = cairo_create (pIcon->pIconBuffer);
+	int i;
+	for (i = 0; cImages[i] != NULL; i ++)
+	{
+		
+		///cairo_dock_set_image_on_icon (pIconContext, cImage, pIcon, pContainer);
+	}
+	cairo_destroy (pIconContext);
+	cairo_dock_redraw_icon (pIcon, pContainer);
+	return TRUE;
+}
+
 static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage, gint iPosition, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
@@ -113,10 +131,18 @@ static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage
 	
 	g_return_val_if_fail (pIcon->pIconBuffer != NULL, FALSE);
 	
-	CairoEmblem *pEmblem = cairo_dock_make_emblem (cImage, pIcon, pContainer);
+	if (cImage == NULL || *cImage == '\0' || strcmp (cImage, "none") == 0)
+	{
+		cairo_dock_remove_overlay_at_position (pIcon, iPosition);
+	}
+	else
+	{
+		cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition);
+	}
+	/**CairoEmblem *pEmblem = cairo_dock_make_emblem (cImage, pIcon);
 	pEmblem->iPosition = iPosition;
 	cairo_dock_draw_emblem_on_icon (pEmblem, pIcon, pContainer);
-	cairo_dock_free_emblem (pEmblem);
+	cairo_dock_free_emblem (pEmblem);*/
 	
 	cairo_dock_redraw_icon (pIcon, pContainer);
 	return TRUE;
@@ -131,7 +157,7 @@ static gboolean _applet_animate (dbusApplet *pDbusApplet, const gchar *cAnimatio
 	
 	if (CAIRO_DOCK_IS_DOCK (pContainer) && cAnimation != NULL)
 	{
-		cairo_dock_request_icon_animation (pIcon, CAIRO_DOCK (pContainer), cAnimation, iNbRounds);
+		cairo_dock_request_icon_animation (pIcon, pContainer, cAnimation, iNbRounds);
 		return TRUE;
 	}
 	return FALSE;
@@ -151,6 +177,7 @@ static gboolean _applet_show_dialog (dbusApplet *pDbusApplet, const gchar *messa
 	return TRUE;
 }
 
+// deprecated
 static gboolean _applet_ask_question (dbusApplet *pDbusApplet, const gchar *cMessage, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
@@ -189,6 +216,7 @@ static gboolean _applet_ask_text (dbusApplet *pDbusApplet, const gchar *cMessage
 	pDbusApplet->pDialog = cairo_dock_show_dialog_with_entry (cMessage, pIcon, pContainer, "same icon", cInitialText, (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_text, pDbusApplet, NULL);
 	return TRUE;
 }
+// end of deprecated
 
 static void _on_text_changed (GtkWidget *pEntry, GtkWidget *pLabel)
 {
@@ -200,7 +228,7 @@ static void _on_text_changed (GtkWidget *pEntry, GtkWidget *pLabel)
 	}
 	else
 	{
-		GtkTextBuffer *pBuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pEntry));
+		GtkTextBuffer *pBuffer = GTK_TEXT_BUFFER (pEntry);
 		iNbChars = gtk_text_buffer_get_char_count (pBuffer);
 	}
 	
@@ -214,6 +242,12 @@ static void _on_text_changed (GtkWidget *pEntry, GtkWidget *pLabel)
 	gtk_label_set_markup (GTK_LABEL (pLabel), cLabel);
 	g_free (cLabel);
 }
+static void _on_dialog_destroyed (dbusApplet *pDbusApplet)
+{
+	CD_APPLET_ENTER;
+	pDbusApplet->pDialog = NULL;
+	CD_APPLET_LEAVE();
+}
 static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDialogAttributes, GHashTable *hWidgetAttributes, const gchar *cIconID, GError **error)
 {
 	g_return_val_if_fail (hDialogAttributes != NULL, FALSE);
@@ -266,9 +300,10 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 		bUseMarkup = g_value_get_boolean (v);
 	
 	attr.pUserData = pDbusApplet;
+	attr.pFreeDataFunc = (GFreeFunc)_on_dialog_destroyed;
 	
 	// attributs du widget interactif.
-	GtkWidget *pWidget = NULL;
+	GtkWidget *pInteractiveWidget = NULL, *pOneWidget = NULL;
 	if (hWidgetAttributes != NULL)  // un widget d'interaction est defini.
 	{
 		v = g_hash_table_lookup (hWidgetAttributes, "widget-type");
@@ -279,7 +314,6 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 			{
 				if (strcmp (cType, "text-entry") == 0)
 				{
-					GtkWidget *pEntry = NULL;
 					gboolean bMultiLines = FALSE;
 					gboolean bEditable = TRUE;
 					gboolean bVisible = TRUE;
@@ -308,16 +342,19 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					
 					if (bMultiLines)
 					{
-						pEntry = gtk_text_view_new ();
-						pWidget = pEntry;
-						gtk_widget_set (pEntry, "width-request", 200, "height-request", 100, NULL);
+						pOneWidget = gtk_text_view_new ();
+						GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
+						gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+						gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pOneWidget);
+						gtk_widget_set (pScrolledWindow, "width-request", 230, "height-request", 130, NULL);
+						pInteractiveWidget = pScrolledWindow;
 						
 						if (! bEditable)
-							gtk_text_view_set_editable (GTK_TEXT_VIEW (pEntry), FALSE);
+							gtk_text_view_set_editable (GTK_TEXT_VIEW (pOneWidget), FALSE);
 						
 						if (cInitialText != NULL)
 						{
-							GtkTextBuffer *pBuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pEntry));
+							GtkTextBuffer *pBuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pOneWidget));
 							gtk_text_buffer_set_text (pBuffer, cInitialText, -1);
 						}
 						
@@ -326,32 +363,42 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					}
 					else
 					{
-						pEntry = gtk_entry_new ();
-						pWidget = pEntry;
-						gtk_entry_set_has_frame (GTK_ENTRY (pEntry), FALSE);
-						gtk_widget_set (pEntry, "width-request", CAIRO_DIALOG_MIN_ENTRY_WIDTH, NULL);
+						pOneWidget = gtk_entry_new ();
+						pInteractiveWidget = pOneWidget;
+						gtk_entry_set_has_frame (GTK_ENTRY (pOneWidget), FALSE);
+						gtk_widget_set (pOneWidget, "width-request", CAIRO_DIALOG_MIN_ENTRY_WIDTH, NULL);
 						if (cInitialText != NULL)
-							gtk_entry_set_text (GTK_ENTRY (pEntry), cInitialText);
+							gtk_entry_set_text (GTK_ENTRY (pOneWidget), cInitialText);
 						if (! bEditable)
-							gtk_editable_set_editable (GTK_EDITABLE (pEntry), FALSE);
+							gtk_editable_set_editable (GTK_EDITABLE (pOneWidget), FALSE);
 						if (! bVisible)
-							gtk_entry_set_visibility (GTK_ENTRY (pEntry), FALSE);
+							gtk_entry_set_visibility (GTK_ENTRY (pOneWidget), FALSE);
 						
 						if (attr.cButtonsImage != NULL)
 							attr.pActionFunc = (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_text_entry;
 					}
 					if (iNbCharsMax != 0)
 					{
-						gchar *cLabel = g_strdup_printf ("<b>%d</b>", cInitialText ? strlen (cInitialText) : 0);
+						gchar *cLabel = g_strdup_printf ("<b>%zd</b>", cInitialText ? strlen (cInitialText) : 0);
 						GtkWidget *pLabel = gtk_label_new (cLabel);
 						g_free (cLabel);
 						gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
 						GtkWidget *pBox = gtk_hbox_new (FALSE, 3);
-						gtk_box_pack_start (GTK_BOX (pBox), pEntry, FALSE, FALSE, 0);
+						gtk_box_pack_start (GTK_BOX (pBox), pInteractiveWidget, TRUE, TRUE, 0);
 						gtk_box_pack_start (GTK_BOX (pBox), pLabel, FALSE, FALSE, 0);
-						pWidget = pBox;
-						g_object_set_data (G_OBJECT (pEntry), "nb-chars-max", GINT_TO_POINTER (iNbCharsMax));
-						g_signal_connect (pEntry, "changed", G_CALLBACK (_on_text_changed), pLabel);
+						pInteractiveWidget = pBox;
+						
+						if (bMultiLines)
+						{
+							GtkTextBuffer *pBuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pOneWidget));
+							g_signal_connect (pBuffer, "changed", G_CALLBACK (_on_text_changed), pLabel);
+							g_object_set_data (G_OBJECT (pBuffer), "nb-chars-max", GINT_TO_POINTER (iNbCharsMax));
+						}
+						else
+						{
+							g_signal_connect (pOneWidget, "changed", G_CALLBACK (_on_text_changed), pLabel);
+							g_object_set_data (G_OBJECT (pOneWidget), "nb-chars-max", GINT_TO_POINTER (iNbCharsMax));
+						}
 					}
 				}
 				else if (strcmp (cType, "scale") == 0)
@@ -391,10 +438,12 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 						cMaxLabel = g_value_get_string (v);
 					
 					pScale = gtk_hscale_new_with_range (fMinValue, fMaxValue, (fMaxValue - fMinValue) / 100.);
+					pOneWidget = pScale;
 					gtk_scale_set_digits (GTK_SCALE (pScale), iNbDigit);
 					gtk_range_set_value (GTK_RANGE (pScale), fInitialValue);
 					
 					gtk_widget_set (pScale, "width-request", 150, NULL);
+					cairo_dock_set_dialog_widget_text_color (pScale);
 					
 					if (cMinLabel || cMaxLabel)
 					{
@@ -408,10 +457,10 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 						pAlign = gtk_alignment_new (1., 1., 0., 0.);
 						gtk_container_add (GTK_CONTAINER (pAlign), label);
 						gtk_box_pack_start (GTK_BOX (pExtendedWidget), pAlign, FALSE, FALSE, 0);
-						pWidget = pExtendedWidget;
+						pInteractiveWidget = pExtendedWidget;
 					}
 					else
-						pWidget = pScale;
+						pInteractiveWidget = pScale;
 					
 					if (attr.cButtonsImage != NULL)
 						attr.pActionFunc = (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_scale;
@@ -436,16 +485,17 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 						cValuesList = g_strsplit (cValues, ";", -1);
 					
 					if (bEditable)
-						pWidget = gtk_combo_box_entry_new_text ();
+						pOneWidget = gtk_combo_box_entry_new_text ();
 					else
-						pWidget = gtk_combo_box_new_text ();
+						pOneWidget = gtk_combo_box_new_text ();
+					pInteractiveWidget = pOneWidget;
 					
 					if (cValuesList != NULL)
 					{
 						int i;
 						for (i = 0; cValuesList[i] != NULL; i ++)
 						{
-							gtk_combo_box_append_text (GTK_COMBO_BOX (pWidget), cValuesList[i]);
+							gtk_combo_box_append_text (GTK_COMBO_BOX (pInteractiveWidget), cValuesList[i]);
 						}
 					}
 					
@@ -456,7 +506,7 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 							cInitialText = g_value_get_string (v);
 						if (cInitialText != NULL)
 						{
-							GtkWidget *pEntry = gtk_bin_get_child (GTK_BIN (pWidget));
+							GtkWidget *pEntry = gtk_bin_get_child (GTK_BIN (pInteractiveWidget));
 							gtk_entry_set_text (GTK_ENTRY (pEntry), cInitialText);
 						}
 					}
@@ -464,7 +514,7 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					{
 						if (v && G_VALUE_HOLDS_INT (v))
 							iInitialValue = g_value_get_int (v);
-						gtk_combo_box_set_active (GTK_COMBO_BOX (pWidget), iInitialValue);
+						gtk_combo_box_set_active (GTK_COMBO_BOX (pInteractiveWidget), iInitialValue);
 					}
 					
 					if (attr.cButtonsImage != NULL)
@@ -480,19 +530,23 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 			}  // fin du type de widget.
 		}
 	}
-	attr.pInteractiveWidget = pWidget;
+	attr.pInteractiveWidget = pInteractiveWidget;
 	
-	if (pWidget == NULL)  // pas de widget, on renverra le numero du bouton appuye.
+	if (pInteractiveWidget == NULL)  // pas de widget, on renverra le numero du bouton appuye.
 	{
 		if (attr.cButtonsImage != NULL)
 			attr.pActionFunc = (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_buttons;
 	}
+	else
+		g_object_set_data (G_OBJECT (pInteractiveWidget), "cd-widget", pOneWidget);
 	
 	if (bUseMarkup)
-		myDialogs.dialogTextDescription.bUseMarkup = TRUE;
+		myDialogsParam.dialogTextDescription.bUseMarkup = TRUE;
 	pDbusApplet->pDialog = cairo_dock_build_dialog (&attr, pIcon, pContainer);
+	if (pOneWidget)
+		gtk_widget_grab_focus (pOneWidget);
 	if (bUseMarkup)
-		myDialogs.dialogTextDescription.bUseMarkup = FALSE;
+		myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
 	
 	g_free (cImageFilePath);
 	if (cButtonsImage)
@@ -535,6 +589,7 @@ gboolean cd_dbus_sub_applet_show_dialog (dbusSubApplet *pDbusSubApplet, const gc
 	return _applet_show_dialog (pDbusSubApplet->pApplet, cMessage, iDuration, cIconID, error);
 }
 
+// deprecated
 gboolean cd_dbus_sub_applet_ask_question (dbusSubApplet *pDbusSubApplet, const gchar *cMessage, const gchar *cIconID, GError **error)
 {
 	return _applet_ask_question (pDbusSubApplet->pApplet, cMessage, cIconID, error);
@@ -549,6 +604,7 @@ gboolean cd_dbus_sub_applet_ask_text (dbusSubApplet *pDbusSubApplet, const gchar
 {
 	return _applet_ask_text (pDbusSubApplet->pApplet, cMessage, cInitialText, cIconID, error);
 }
+// end of deprecated
 
 gboolean cd_dbus_sub_applet_popup_dialog (dbusSubApplet *pDbusSubApplet, GHashTable *hDialogAttributes, GHashTable *hWidgetAttributes, const gchar *cIconID, GError **error)
 {
@@ -622,8 +678,8 @@ gboolean cd_dbus_sub_applet_add_sub_icons (dbusSubApplet *pDbusSubApplet, const
 			pIcon->pSubDock = NULL;
 		}
 		pInstance->pDesklet->icons = g_list_concat (pInstance->pDesklet->icons, pIconsList);
-		gpointer data[2] = {GINT_TO_POINTER (TRUE), GINT_TO_POINTER (FALSE)};
-		cairo_dock_set_desklet_renderer_by_name (pInstance->pDesklet, "Caroussel", (CairoDeskletRendererConfigPtr) data);
+		gpointer data[3] = {GINT_TO_POINTER (0), GINT_TO_POINTER (TRUE), NULL};
+		cairo_dock_set_desklet_renderer_by_name (pInstance->pDesklet, "Panel", (CairoDeskletRendererConfigPtr) data);
 	}
 	
 	return TRUE;
@@ -741,6 +797,7 @@ gboolean cd_dbus_applet_show_dialog (dbusApplet *pDbusApplet, const gchar *messa
 	return _applet_show_dialog (pDbusApplet, message, iDuration, NULL, error);
 }
 
+// deprecated
 gboolean cd_dbus_applet_ask_question (dbusApplet *pDbusApplet, const gchar *message, GError **error)
 {
 	cd_debug ("%s (%s)\n", __func__, message);
@@ -758,6 +815,7 @@ gboolean cd_dbus_applet_ask_text (dbusApplet *pDbusApplet, const gchar *message,
 	cd_debug ("%s (%s)\n", __func__, message);
 	return _applet_ask_text (pDbusApplet, message, cInitialText, NULL, error);
 }
+// end of deprecated
 
 gboolean cd_dbus_applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDialogAttributes, GHashTable *hWidgetAttributes, GError **error)
 {
@@ -792,19 +850,20 @@ gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar
 		memset (&attr, 0, sizeof (CairoGraphAttribute));
 		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
 		pRenderAttr->cModelName = "graph";
-		pRenderAttr->iMemorySize = (pIcon->fWidth > 1 ? pIcon->fWidth : 32);  // fWidht peut etre <= 1 en mode desklet au chargement.
+		int w, h;
+		cairo_dock_get_icon_extent (pIcon, &w, &h);
+		pRenderAttr->iMemorySize = (w > 1 ? w : 32);
 		// Line;Plain;Bar;Circle;Plain Circle
 		if (cTheme == NULL || strcmp (cTheme, "Line") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH2_LINE;
+			attr.iType = CAIRO_DOCK_GRAPH_LINE;
 		else if (strcmp (cTheme, "Plain") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH2_PLAIN;
+			attr.iType = CAIRO_DOCK_GRAPH_PLAIN;
 		else if (strcmp (cTheme, "Bar") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH2_BAR;
+			attr.iType = CAIRO_DOCK_GRAPH_BAR;
 		else if (strcmp (cTheme, "Circle") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH2_CIRCLE;
+			attr.iType = CAIRO_DOCK_GRAPH_CIRCLE;
 		else if (strcmp (cTheme, "Plain Circle") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH2_CIRCLE_PLAIN;
-		attr.iRadius = 10;
+			attr.iType = CAIRO_DOCK_GRAPH_CIRCLE_PLAIN;
 		attr.bMixGraphs = FALSE;
 		double *fHighColor = g_new (double, iNbValues*3);
 		double *fLowColor = g_new (double, iNbValues*3);
@@ -878,9 +937,11 @@ gboolean cd_dbus_applet_control_appli (dbusApplet *pDbusApplet, const gchar *cAp
 	if (cairo_dock_strings_differ (pIcon->cClass, cClass))
 	{
 		if (pIcon->cClass != NULL)
-			cairo_dock_deinhibate_class (pIcon->cClass, pIcon);
+			cairo_dock_deinhibite_class (pIcon->cClass, pIcon);
 		if (cClass != NULL)
-			cairo_dock_inhibate_class (cClass, pIcon);
+		{
+			cairo_dock_inhibite_class (cClass, pIcon);  /// useful to use cairo_dock_register_class ?...
+		}
 		if (! cairo_dock_is_loading ())
 		{
 			CairoContainer *pContainer = pInstance->pContainer;
@@ -1075,6 +1136,9 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 					{
 						image = gtk_image_new_from_stock (cIcon, GTK_ICON_SIZE_MENU);
 					}
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+					gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
+#endif
 					gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
 				}
 			}
@@ -1169,6 +1233,7 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 			bCouldBind = cd_keybinder_bind (cShortkey, (CDBindkeyHandler) cd_dbus_applet_emit_on_shortkey, pDbusApplet);
 			if (bCouldBind)
 				pDbusApplet->pShortkeyList = g_list_prepend (pDbusApplet->pShortkeyList, g_strdup (cShortkey));
+			cd_debug ("*** bind %s: %d", cShortkey, bCouldBind);
 		}
 	}
 	return TRUE;
@@ -1218,7 +1283,7 @@ gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GV
 	}
 	else if (strcmp (cProperty, "orientation") == 0)
 	{
-		CairoDockPositionType iScreenBorder = (g_pMainDock ? ((! g_pMainDock->container.bIsHorizontal) << 1) | (! g_pMainDock->container.bDirectionUp) : 0);
+		CairoDockPositionType iScreenBorder = ((! pContainer->bIsHorizontal) << 1) | (! pContainer->bDirectionUp);
 		g_value_init (v, G_TYPE_UINT);
 		g_value_set_uint (v, iScreenBorder);
 	}
@@ -1230,14 +1295,26 @@ gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GV
 	else if (strcmp (cProperty, "width") == 0)
 	{
 		int iWidth, iHeight;
-		cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
+		if (pInstance->pDock)
+		{
+			double a = cairo_dock_get_max_scale (pContainer);
+			double s = pInstance->pDock->fMagnitudeMax;
+			iWidth /= (1 + a) / (1 + s*a);
+		}
 		g_value_init (v, G_TYPE_INT);
 		g_value_set_int (v, iWidth);
 	}
 	else if (strcmp (cProperty, "height") == 0)
 	{
 		int iWidth, iHeight;
-		cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
+		if (pInstance->pDock)
+		{
+			double a = cairo_dock_get_max_scale (pContainer);
+			double s = pInstance->pDock->fMagnitudeMax;
+			iHeight /= (1 + a) / (1 + s*a);
+		}
 		g_value_init (v, G_TYPE_INT);
 		g_value_set_int (v, iHeight);
 	}
@@ -1286,7 +1363,14 @@ gboolean cd_dbus_applet_get_all (dbusApplet *pDbusApplet, GHashTable **hProperti
 	}
 	CairoDockPositionType iScreenBorder = ((! pContainer->bIsHorizontal) << 1) | (! pContainer->bDirectionUp);
 	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
+	if (pInstance->pDock)
+	{
+		double a = cairo_dock_get_max_scale (pContainer);
+		double s = pInstance->pDock->fMagnitudeMax;
+		iWidth /= (1 + a) / (1 + s*a);
+		iHeight /= (1 + a) / (1 + s*a);
+	}
 	
 	Window Xid = pIcon->Xid;
 	gboolean bHasFocus = (pIcon->Xid != 0 && pIcon->Xid == cairo_dock_get_current_active_window ());
