@@ -24,13 +24,16 @@
 
 #include <cairo-dock.h>
 
-
+gboolean _check_size_is_constant (CairoDockModuleInstance *myApplet, const gchar *cFilePath);
+gboolean _new_xml_to_conf (CairoDockModuleInstance *myApplet, gchar *cReceivedData);
 
 //~ CD_APPLET_ON_CLICK_H
+//~ CD_APPLET_ON_DOUBLE_CLICK_H
 
 CD_APPLET_ON_BUILD_MENU_H
 
 //~ CD_APPLET_ON_SCROLL_H
+CD_APPLET_ON_DROP_DATA_H
 
 CD_APPLET_ON_MIDDLE_CLICK_H
 
