@@ -27,12 +27,15 @@
 #include "applet-init.h"
 
 
-CD_APPLET_DEFINITION (N_("Messaging Menu"),
+CD_APPLET_DEFINE_BEGIN (N_("Messaging Menu"),
 	2, 2, 0,
 	CAIRO_DOCK_CATEGORY_APPLET_INTERNET,
 	N_("A menu that notices you about new messages from Mail or Chat applications.\n"
 	"It handles Evolution, Pidgin, Empathy, etc"),
 	"Fabounet")
+	CD_APPLET_DEFINE_COMMON_APPLET_INTERFACE
+	CD_APPLET_ALLOW_EMPTY_TITLE
+CD_APPLET_DEFINE_END
 
 
 //\___________ Here is where you initiate your applet. myConfig is already set at this point, and also myIcon, myContainer, myDock, myDesklet (and myDrawContext if you're in dock mode). The macro CD_APPLET_MY_CONF_FILE and CD_APPLET_MY_KEY_FILE can give you access to the applet's conf-file and its corresponding key-file (also available during reload). If you're in desklet mode, myDrawContext is still NULL, and myIcon's buffers has not been filled, because you may not need them then (idem when reloading).
