@@ -45,7 +45,7 @@ static inline int _cd_do_get_matching_icons_width (int *iNbIcons)
 		if (pIcon->pIconBuffer == NULL && pIcon->iIconTexture == 0)  // icone pas encore chargee.
 			continue;
 		pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-		cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
+		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 		if (iHeight != 0)
 		{
 			fZoom = (double) g_pMainDock->container.iHeight/2 / iHeight;
@@ -71,7 +71,7 @@ static inline int _cd_do_get_icon_x (GList *pElement)
 		if (pIcon->pIconBuffer == NULL && pIcon->iIconTexture == 0)  // icone pas encore chargee.
 			continue;
 		pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-		cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
+		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 		if (iHeight != 0)
 		{
 			fZoom = (double) g_pMainDock->container.iHeight/2 / iHeight;
@@ -161,7 +161,7 @@ void cd_do_render_cairo (CairoDock *pMainDock, cairo_t *pCairoContext)
 				if (pIcon->pIconBuffer == NULL)  // icone pas encore chargee.
 					continue;
 				pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-				cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
+				cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 				fZoom = fIconScale * pMainDock->container.iHeight/2 / iHeight * (myData.pCurrentMatchingElement == ic ? 1. : 1.);
 				cairo_save (pCairoContext);
 				
@@ -346,7 +346,7 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 				if (pIcon->iIconTexture == 0)  // icone pas encore chargee.
 					continue;
 				pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-				cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
+				cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 				fZoom = (double) pMainDock->container.iHeight/2 / iHeight * (myData.pCurrentMatchingElement == ic ? 1. : 1.);
 				glPushMatrix ();
 				
@@ -406,7 +406,7 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 		double fFrameWidth = myData.iTextWidth;
 		double fTextScale = (fFrameWidth > pMainDock->container.iWidth ? (double) pMainDock->container.iWidth / fFrameWidth : 1.);
 		double fFrameHeight = myData.iTextHeight;
-		double fRadius = myBackground.iDockRadius * myConfig.fFontSizeRatio;
+		double fRadius = myDocksParam.iDockRadius * myConfig.fFontSizeRatio;
 		double fLineWidth = 0.;
 		
 		double fDockOffsetX, fDockOffsetY;  // Offset du coin haut gauche du cadre.
