@@ -23,11 +23,17 @@
 #include <cairo-dock.h>
 
 
+void cd_satus_notifier_add_new_item (const gchar *cService, const gchar *cObjectPath, int iPosition);
+
+void cd_satus_notifier_remove_item (const gchar *cService, int iPosition);
+
+
 void cd_satus_notifier_launch_service (void);
 
-
 void cd_satus_notifier_stop_service (void);
 
+void cd_satus_notifier_launch_our_watcher (void);
+
 
 void cd_satus_notifier_add_theme_path (const gchar * cThemePath);
 
