@@ -19,6 +19,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
 
 #include "applet-struct.h"
 #include "applet-item.h"
@@ -82,17 +83,51 @@ static inline CDStatusNotifierItem *_get_item (Icon *pClickedIcon, CairoContaine
 	return pItem;
 }
 
+
+static inline gboolean _popup_menu (CDStatusNotifierItem *pItem, Icon *pIcon, CairoContainer *pContainer)
+{
+	gboolean r = FALSE;
+	if (pItem->cMenuPath != NULL)
+	{
+		if (pItem->pMenu == NULL)
+			pItem->pMenu = dbusmenu_gtkmenu_new ((gchar *)pItem->cService, (gchar *)pItem->cMenuPath);
+		if (pItem->pMenu != NULL)
+		{
+			cairo_dock_popup_menu_on_icon (GTK_WIDGET (pItem->pMenu), pIcon, pContainer);
+			r = TRUE;
+		}
+	}
+
+	if (!r)
+	{
+		r = _emit_click (pItem, pIcon, pContainer, "ContextMenu");
+	}
+
+	if (!r)
+	{
+		r = _emit_click (pItem, pIcon, pContainer, "Activate");
+	}
+}
+
 CD_APPLET_ON_CLICK_BEGIN
 	CDStatusNotifierItem *pItem = _get_item (CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER);
 	//g_print ("click on item '%s'\n", pItem?pItem->cService:"none");
 	if (pItem != NULL)
 	{
-		gboolean r = _emit_click (pItem, CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER, "Activate");
-		if (!r)
+		if (myConfig.bMenuOnLeftClick)
 		{
-			if (pItem->cId != NULL)
+			_popup_menu (pItem, CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER);
+		}
+		else
+		{
+			gboolean r = _emit_click (pItem, CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER, "Activate");
+			if (!r)
 			{
-				cairo_dock_launch_command (pItem->cId);  // lancer une nouvelle fois l'appli montre sa fenetre (enfin, generalement).
+				if (pItem->cId != NULL)
+				{
+					/// TODO: try to get the icon in the taskbar, because launch the command doesn't raise the window if it was already visible (but it does pop up it if it was hidden, usually).
+					cairo_dock_launch_command (pItem->cId);  // lancer une nouvelle fois l'appli montre sa fenetre (enfin, generalement).
+				}
 			}
 		}
 	}
@@ -136,29 +171,15 @@ CD_APPLET_ON_BUILD_MENU_END
 
 gboolean cd_status_notifier_on_right_click (CairoDockModuleInstance *myApplet, Icon *pClickedIcon, CairoContainer *pClickedContainer, GtkWidget *pAppletMenu, gboolean *bDiscardMenu)
 {
-	if (pClickedIcon == NULL)
+	if (pClickedIcon == NULL || myConfig.bMenuOnLeftClick)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	CD_APPLET_ENTER;
-	CDStatusNotifierItem *pItem = _get_item (CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER);
+	CDStatusNotifierItem *pItem = _get_item (pClickedIcon, pClickedContainer);
 	if (pItem != NULL)
 	{
-		gboolean r = FALSE;
-		if (pItem->cMenuPath != NULL)
-		{
-			if (pItem->pMenu == NULL)
-				pItem->pMenu = dbusmenu_gtkmenu_new ((gchar *)pItem->cService, (gchar *)pItem->cMenuPath);
-			if (pItem->pMenu != NULL)
-			{
-				cairo_dock_popup_menu_on_icon (GTK_WIDGET (pItem->pMenu), pClickedIcon, pClickedContainer);
-				r = TRUE;
-			}
-		}
-		
-		if (!r)
-		{
-			_emit_click (pItem, pClickedIcon, pClickedContainer, "ContextMenu");
-		}
+		_popup_menu (pItem, pClickedIcon, pClickedContainer);
+
 		*bDiscardMenu = TRUE;
 		CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
 	}
@@ -171,7 +192,7 @@ static gboolean _popup_tooltip (Icon *pIcon)
 	CDStatusNotifierItem *pItemData = CD_APPLET_GET_MY_ICON_DATA (pIcon);
 	if (pItemData != NULL && pItemData->pToolTip != NULL)
 	{
-		myDialogs.dialogTextDescription.bUseMarkup = TRUE;
+		myDialogsParam.dialogTextDescription.bUseMarkup = TRUE;
 		//g_print ("pItemData->pToolTip->cMessage : %s\n", pItemData->pToolTip->cMessage);
 		gchar *cText = g_strdup_printf ("<b>%s</b>\n%s", pItemData->pToolTip->cTitle, pItemData->pToolTip->cMessage);
 		gchar *cIconPath = NULL;
@@ -182,7 +203,7 @@ static gboolean _popup_tooltip (Icon *pIcon)
 		
 		cairo_dock_show_temporary_dialog_with_icon (cText, pIcon, CAIRO_CONTAINER (myIcon->pSubDock), 3000, cIconPath ? cIconPath : "same icon");
 		g_free (cText);
-		myDialogs.dialogTextDescription.bUseMarkup = FALSE;
+		myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
 		pItemData->iSidPopupTooltip = 0;
 	}
 	return FALSE;
@@ -213,3 +234,96 @@ gboolean cd_status_notifier_on_enter_icon (CairoDockModuleInstance *myApplet, Ic
 	}
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
+
+
+
+gboolean on_mouse_moved (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bStartAnimation)
+{
+	CD_APPLET_ENTER;
+	if (! myIcon->bPointed || ! pContainer->bInside)
+		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	
+	CDStatusNotifierItem *pItem = cd_satus_notifier_find_item_from_coord ();
+	
+	if (pItem != myData.pCurrentlyHoveredItem)
+	{
+		myData.pCurrentlyHoveredItem = pItem;
+		myData.fDesktopNameAlpha = 0.;
+		if (pItem == NULL)
+			CD_APPLET_SET_NAME_FOR_MY_ICON (NULL);
+		else
+			CD_APPLET_SET_NAME_FOR_MY_ICON (pItem->cLabel ? pItem->cLabel : pItem->cTitle ? pItem->cTitle : pItem->cId);
+		
+		if (myDock)
+			CAIRO_DOCK_REDRAW_MY_CONTAINER;
+		else
+			*bStartAnimation = TRUE;
+	}
+	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+}
+
+gboolean on_update_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bContinueAnimation)
+{
+	CD_APPLET_ENTER;
+	if (! myIcon->bPointed || ! pContainer->bInside)
+	{
+		myData.fDesktopNameAlpha -= .07;
+		if (myData.fDesktopNameAlpha < .01)
+			myData.fDesktopNameAlpha = 0;
+		if (myData.fDesktopNameAlpha != 0)
+			*bContinueAnimation = TRUE;
+	}
+	else
+	{
+		myData.fDesktopNameAlpha += .07;
+		if (myData.fDesktopNameAlpha > .99)
+			myData.fDesktopNameAlpha = 1;
+		if (myData.fDesktopNameAlpha != 1)
+			*bContinueAnimation = TRUE;
+	}
+	CAIRO_DOCK_REDRAW_MY_CONTAINER;
+	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+}
+
+gboolean on_render_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, cairo_t *pCairoContext)
+{
+	CD_APPLET_ENTER;
+	int x, y;  // centre du texte.
+	x = myIcon->fDrawX + myIcon->fWidth * myIcon->fScale / 2;
+	y = myIcon->fDrawY + myIcon->fHeight * myIcon->fScale / 2;
+	if (x - myIcon->iTextWidth/2 < 0)
+	{
+		x -= myIcon->iTextWidth/2;
+	}
+	if (pCairoContext != NULL)
+	{
+		if (myIcon->pTextBuffer == NULL)
+			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		cairo_save (pCairoContext);
+		cairo_translate (pCairoContext, x, y);
+		cairo_set_source_surface (pCairoContext, myIcon->pTextBuffer, - myIcon->iTextWidth/2, - myIcon->iTextHeight/2);
+		cairo_paint_with_alpha (pCairoContext, myData.fDesktopNameAlpha);
+		cairo_restore (pCairoContext);
+	}
+	else
+	{
+		if (myIcon->iLabelTexture == 0)
+			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		glPushMatrix ();
+		if (myDesklet)
+			glTranslatef (-myDesklet->container.iWidth/2, -myDesklet->container.iHeight/2, -myDesklet->container.iHeight*(sqrt(3)/2));
+		glTranslatef (x - ((myIcon->iTextWidth & 1) ? 0.5 : 0.),
+			y - ((myIcon->iTextHeight & 1) ? 0.5 : 0.),
+			0);
+		cairo_dock_draw_texture_with_alpha (myIcon->iLabelTexture, myIcon->iTextWidth, myIcon->iTextHeight, myData.fDesktopNameAlpha);
+		glPopMatrix ();
+	}
+	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+}
+
+gboolean on_leave_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bStartAnimation)
+{
+	*bStartAnimation = TRUE;
+	myData.pCurrentlyHoveredItem = NULL;
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+}
