@@ -246,6 +246,8 @@ GtkWidget *mixer_build_widget (gboolean bHorizontal)
 		G_CALLBACK (on_change_volume),
 		NULL);
 	
+	cairo_dock_set_dialog_widget_text_color (pScale);
+	
 	return pScale;
 }
 
@@ -262,24 +264,10 @@ void mixer_set_volume_with_no_callback (GtkWidget *pScale, int iVolume)
 }
 
 
-/**static gboolean on_button_press_dialog (GtkWidget *widget,
-	GdkEventButton *pButton,
-	CairoDialog *pDialog)
-{
-	CD_APPLET_ENTER;
-	cairo_dock_dialog_unreference (pDialog);
-	myData.pDialog = NULL;
-	CD_APPLET_LEAVE(FALSE);
-	//return FALSE;
-}*/
 static void _on_dialog_destroyed (CairoDockModuleInstance *myApplet)
 {
 	myData.pDialog = NULL;
 }
-/**static gboolean _on_key_press_dialog (int iClickedButton, GtkWidget *pInteractiveWidget, gpointer *data, CairoDialog *pDialog)
-{
-	myData.pDialog = NULL;  // le dialogue est dereference donc tout ce qu'on a a faire c'est prendre en compte ce fait !
-}*/
 void mixer_show_hide_dialog (void)
 {
 	if (myDesklet)
@@ -301,15 +289,10 @@ void mixer_show_hide_dialog (void)
 		attr.cText = cMessage;
 		attr.cImageFilePath = MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE;
 		attr.pInteractiveWidget = pScale;
-		///attr.pActionFunc = (CairoDockActionOnAnswerFunc) _on_key_press_dialog;
 		attr.pUserData = myApplet;
 		attr.pFreeDataFunc = (GFreeFunc)_on_dialog_destroyed;
 		
 		myData.pDialog = cairo_dock_build_dialog (&attr, myIcon, myContainer);
-		/**g_signal_connect (G_OBJECT (myData.pDialog->container.pWidget),
-			"button-press-event",
-			G_CALLBACK (on_button_press_dialog),
-			myData.pDialog);*/
 	}
 	else
 	{
@@ -323,5 +306,4 @@ gboolean mixer_check_events (gpointer data)
 	CD_APPLET_ENTER;
 	snd_mixer_handle_events (myData.mixer_handle);  // ne renvoie pas d'evenements pour nos actions !
 	CD_APPLET_LEAVE(TRUE);
-	//return TRUE;
 }
