@@ -297,6 +297,15 @@ static void _send_clipboard (GtkMenuItem *menu_item, gpointer *data)
 	CD_APPLET_LEAVE ();
 }
 
+// checkbox => Use only a file web hosting
+static void _set_use_only_file_type (GtkCheckMenuItem *pMenuItem, gpointer *data)
+{
+	myConfig.bUseOnlyFileType = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (pMenuItem));
+	cairo_dock_update_conf_file (CD_APPLET_MY_CONF_FILE,
+		G_TYPE_BOOLEAN, "Configuration", "only file type", myConfig.bUseOnlyFileType,
+		G_TYPE_INVALID); // updated the config file => maybe not needed if we want a temporary status
+}
+
 
 //\___________ Define here the action to be taken when the user left-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons.
 CD_APPLET_ON_CLICK_BEGIN
@@ -305,7 +314,7 @@ CD_APPLET_ON_CLICK_END
 
 
 CD_APPLET_ON_DROP_DATA_BEGIN
-	g_print  ("DND2SHARE : drop de '%s'\n", CD_APPLET_RECEIVED_DATA);
+	cd_debug  ("DND2SHARE : drop de '%s'", CD_APPLET_RECEIVED_DATA);
 	_on_drop_data (CD_APPLET_RECEIVED_DATA);
 CD_APPLET_ON_DROP_DATA_END
 
@@ -394,16 +403,18 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Send the clipboard's content"), GTK_STOCK_PASTE, _send_clipboard, CD_APPLET_MY_MENU);
 	
-	GtkWidget *pHistoryMenu = gtk_menu_new ();
+	GtkWidget *pHistoryMenu = gtk_menu_new ();  // we don't use CD_APPLET_ADD_SUB_MENU_WITH_IMAGE, because we want to be able to set the menu-item unsensitive.
 	GtkWidget *mi = gtk_image_menu_item_new_with_label (D_("History"));
-	
+
 	GtkWidget *im = gtk_image_new_from_stock (GTK_STOCK_INDEX, GTK_ICON_SIZE_MENU);
+	#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (mi), TRUE);
+	#endif
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), im);
-	
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (CD_APPLET_MY_MENU), mi); 
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mi), pHistoryMenu);
 	
-	//GtkWidget *pHistoryMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("History"), CD_APPLET_MY_MENU, GTK_STOCK_INDEX);
 	if (myData.pUpoadedItems != NULL)
 	{
 		CDSiteBackend *pBackend;
@@ -441,7 +452,10 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 			}
 			if (cPreview == NULL)
 			{
-				cairo_dock_fm_get_file_info (pItem->cLocalPath, &cName, &cURI, &cPreview, &bIsDirectory, &iVolumeID, &fOrder, 0);
+				gchar *cIconName = NULL;
+				cairo_dock_fm_get_file_info (pItem->cLocalPath, &cName, &cURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, 0);
+				cPreview = cairo_dock_search_icon_s_path (cIconName);
+				g_free (cIconName);
 				g_free (cName);
 				cName = NULL;
 				g_free (cURI);
@@ -478,6 +492,12 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	}
 	else
 		gtk_widget_set_sensitive (GTK_WIDGET (mi), FALSE);
-	
+
+	pMenuItem = gtk_check_menu_item_new_with_label (D_("Use only a files hosting site"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (CD_APPLET_MY_MENU), pMenuItem);
+	if (myConfig.bUseOnlyFileType)
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (pMenuItem), TRUE);
+	g_signal_connect (G_OBJECT (pMenuItem), "toggled", G_CALLBACK (_set_use_only_file_type), NULL);
+
 	CD_APPLET_ADD_ABOUT_IN_MENU (pModuleSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
