@@ -23,15 +23,51 @@
 
 #include <cairo-dock.h>
 
+#define CD_REBOOT_NEEDED_FILE "/var/run/reboot-required"
+
+typedef enum {
+	CD_LOGOUT=0,
+	CD_SHUTDOWN,
+	CD_LOCK_SCREEN,
+	CD_NB_ACTIONS
+	} CDActionsEnum;
+
+typedef enum {
+	CD_RESTART,
+	CD_STOP,
+	CD_SUSPEND,
+	CD_HIBERNATE,
+	CD_LOG_OUT,
+	CD_NB_COMMANDS
+	} CDCommandsEnum;
+
 struct _AppletConfig {
 	gchar *cUserAction;
 	gchar *cUserAction2;
-	gboolean bInvertButtons;
+	CDActionsEnum iActionOnClick;
+	CDActionsEnum iActionOnMiddleClick;
 	gint iShutdownTime;  // time_t
+	gchar *cEmblemPath;
+	gchar *cDefaultLabel;
 	} ;
 
+typedef struct {
+	gboolean bCanHibernate;
+	gboolean bCanSuspend;
+	gboolean bCanStop;
+	gboolean bCanRestart;
+	} CDSharedMemory;
+
 struct _AppletData {
 	guint iSidTimer;
+	gboolean bRebootNeeded;
+	// manual capabilities.
+	CairoDockTask *pTask;
+	gboolean bCapabilitiesChecked;
+	gboolean bCanHibernate;
+	gboolean bCanSuspend;
+	gboolean bCanStop;
+	gboolean bCanRestart;
 	} ;
 
 #endif
