@@ -29,10 +29,10 @@ typedef void (*cd_mail_fill_account)(CDMailAccount *mailaccount, GKeyFile *pKeyF
 typedef void (*cd_mail_create_account)( GKeyFile *pKeyFile, const gchar *pMailAccountName );
 
 struct storage_type_def {
-  const gchar * name;
-  const gchar * description;
-  cd_mail_fill_account pfillFunc;
-  cd_mail_create_account pcreateFunc;
+	const gchar * name;
+	const gchar * description;
+	cd_mail_fill_account pfillFunc;
+	cd_mail_create_account pcreateFunc;
 };
 
 static struct storage_type_def storage_tab[] = {
@@ -41,7 +41,15 @@ static struct storage_type_def storage_tab[] = {
 	{"mbox", "MBox", cd_mail_retrieve_mbox_params, cd_mail_create_mbox_params },
 	{"mh", "MH", cd_mail_retrieve_mh_params, cd_mail_create_mh_params },
 	{"maildir", "MailDir", cd_mail_retrieve_maildir_params , cd_mail_create_maildir_params},
-	{"gmail", "GMail", cd_mail_retrieve_gmail_params, cd_mail_create_gmail_params }
+	{"gmail", "GMail", cd_mail_retrieve_gmail_params, cd_mail_create_gmail_params },
+	{"yahoo", "Yahoo!", cd_mail_retrieve_yahoo_params, cd_mail_create_yahoo_params },
+	{"hotmail", "Hotmail / Live", cd_mail_retrieve_hotmail_params, cd_mail_create_hotmail_params },
+	{"free", "Free", cd_mail_retrieve_free_params, cd_mail_create_free_params },
+	{"neuf", "Neuf Télécom", cd_mail_retrieve_neuf_params, cd_mail_create_neuf_params },
+	{"sfr", "SFR", cd_mail_retrieve_sfr_params, cd_mail_create_sfr_params },
+	{"orange", "Orange", cd_mail_retrieve_orange_params, cd_mail_create_orange_params },
+	{"uclouvain", "UCLouvain", cd_mail_retrieve_uclouvain_params, cd_mail_create_uclouvain_params },
+	{"skynet", "Skynet (Belgacom)", cd_mail_retrieve_skynet_params, cd_mail_create_skynet_params }
 #if ( __WORDSIZE == 64 )
 /* in 64bit libetpan crashes with RSS, so... avoid it. */
 #warning "Compilation 64bits: avoiding RSS accounts"
@@ -78,7 +86,7 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 	guint j;
 	gsize i, length = 0;
 	gboolean bFlushConfFileNeeded = FALSE;
-		gchar **pGroupList = g_key_file_get_groups (pKeyFile, &length);
+	gchar **pGroupList = g_key_file_get_groups (pKeyFile, &length);
 	myData.pMailAccounts = g_ptr_array_sized_new (length - 3);
 	
 	cd_debug ("recuperons les comptes ...\n");
@@ -117,25 +125,40 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 		pMailAccount->timeout = CD_CONFIG_GET_INTEGER_WITH_DEFAULT (cMailAccountName, "timeout mn", 10);
 		pMailAccount->pAppletInstance = myApplet;
 		pMailAccount->cMailApp = g_key_file_get_string (pKeyFile, cMailAccountName, "mail application", NULL);  // a specific mail application to launch for this account, if any.
+		if (pMailAccount->cMailApp && *pMailAccount->cMailApp == '\0')
+		{
+			g_free (pMailAccount->cMailApp);
+			pMailAccount->cMailApp = NULL;
+		}
 		(storage_tab[j].pfillFunc)( pMailAccount, pKeyFile, cMailAccountName );
 	}
 	g_strfreev (pGroupList);
 }
 
+#define _find_image_path(path) \
+	__extension__ ({\
+	gchar *_found_image = NULL; \
+	if (path != NULL) { \
+		_found_image = cairo_dock_search_image_s_path (path); \
+		if (_found_image == NULL)\
+			_found_image = cairo_dock_search_icon_s_path (path); }\
+	_found_image; })
 CD_APPLET_GET_CONFIG_BEGIN
 	//\_________________ On recupere toutes les valeurs de notre fichier de conf.
 	gchar *path;
 	path = CD_CONFIG_GET_STRING ("Configuration", "no mail image");
-	myConfig.cNoMailUserImage = (path?cairo_dock_generate_file_path (path):NULL);
+	myConfig.cNoMailUserImage = _find_image_path (path);
 	g_free (path);
 	path = CD_CONFIG_GET_STRING ("Configuration", "has mail image");
-	myConfig.cHasMailUserImage = (path?cairo_dock_generate_file_path (path):NULL);
+	myConfig.cHasMailUserImage = _find_image_path (path);
 	g_free (path);
 	myConfig.bPlaySound = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "play sound", TRUE);
 	path = CD_CONFIG_GET_STRING ("Configuration", "new mail sound");
 	myConfig.cNewMailUserSound = (path?cairo_dock_generate_file_path (path):NULL);
 	g_free (path);
 
+	myConfig.cAnimation = CD_CONFIG_GET_STRING ("Configuration", "animation");
+	myConfig.iAnimationDuration = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "anim duration", 5);
 	myConfig.cMailApplication = CD_CONFIG_GET_STRING ("Configuration", "mail application");
 	/**myConfig.cMailClass = CD_CONFIG_GET_STRING ("Configuration", "mail class");
 	myConfig.bStealTaskBarIcon = myConfig.cMailApplication && CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "inhibate appli", TRUE);*/
@@ -163,6 +186,7 @@ CD_APPLET_RESET_CONFIG_BEGIN
 	g_free( myConfig.cHasMailUserImage );
 	g_free( myConfig.cNewMailUserSound );
 	g_free( myConfig.cMailApplication );
+	g_free( myConfig.cAnimation );
 	///g_free( myConfig.cMailClass );
 	g_free (myConfig.cThemePath);
 	g_free (myConfig.cRenderer);
@@ -327,7 +351,7 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 {
 	cd_debug ("");
 	//\____________ On recupere notre widget personnalise (un simple container vide qu'on va remplir avec nos trucs).
-	CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_get_group_key_widget_from_name ("Configuration", "add account");
+	CairoDockGroupKeyWidget *pGroupKeyWidget = CD_APPLET_GET_CONFIG_PANEL_GROUP_KEY_WIDGET ("Configuration", "add account");
 	g_return_if_fail (pGroupKeyWidget != NULL);
 	
 	GtkWidget *pCustomWidgetBox = gtk_hbox_new (FALSE, 3);
@@ -341,12 +365,12 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 	GtkWidget *pMailTypesCombo = gtk_combo_box_new_text();
 	if( pMailTypesCombo )
 	{
-       guint j;
-        for( j = 0; j < MAIL_NB_STORAGE_TYPES; j++ )
-        {
-          gtk_combo_box_append_text( GTK_COMBO_BOX (pMailTypesCombo), storage_tab[j].description );
-          //gtk_widget_set_tooltip_text (pMenuItem, D_("description du type de compte"));
-        }
+		guint j;
+		for( j = 0; j < MAIL_NB_STORAGE_TYPES; j++ )
+		{
+			gtk_combo_box_append_text( GTK_COMBO_BOX (pMailTypesCombo), storage_tab[j].description );
+			//gtk_widget_set_tooltip_text (pMenuItem, D_("description du type de compte"));
+		}
 	}
 	gtk_box_pack_start (GTK_BOX (pCustomWidgetBox),
 		pMailTypesCombo,
@@ -371,8 +395,8 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 
 	//\____________ On cree un bouton pour ajouter un compte mail et on l'ajoute dans notre container.
 	GtkWidget *pButton = gtk_button_new_from_stock (GTK_STOCK_ADD);
-    g_object_set_data (G_OBJECT (pButton), "MailTypesCombo", pMailTypesCombo); // associer le bouton add avec le combo
-    g_object_set_data (G_OBJECT (pButton), "MailNameEntry", pEntry); // associer le bouton add avec le texte du nom
+	g_object_set_data (G_OBJECT (pButton), "MailTypesCombo", pMailTypesCombo); // associer le bouton add avec le combo
+	g_object_set_data (G_OBJECT (pButton), "MailNameEntry", pEntry); // associer le bouton add avec le texte du nom
 	g_signal_connect (G_OBJECT (pButton),
 		"clicked",
 		G_CALLBACK (_cd_mail_add_account),
@@ -404,7 +428,7 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 		}
 		
 		//\____________ On recupere notre widget personnalise (un simple container vide qu'on va remplir avec nos trucs).
-		CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_get_group_key_widget_from_name (cMailAccountName, "remove account");
+		CairoDockGroupKeyWidget *pGroupKeyWidget = CD_APPLET_GET_CONFIG_PANEL_GROUP_KEY_WIDGET (cMailAccountName, "remove account");
 		if( pGroupKeyWidget == NULL )
 		{
 			cd_warning ("mail : oups, there is a problem in the conf file");
