@@ -43,7 +43,6 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.iNotificationDuration = CD_CONFIG_GET_INTEGER ("Configuration", "notif_duration");
 	
 	myConfig.lowBatteryValue = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "low value", 15);
-	myConfig.bUseDBusFallback = CD_CONFIG_GET_BOOLEAN ("Configuration", "use_dbus");
 	
 	if (! g_key_file_has_key (CD_APPLET_MY_KEY_FILE, "Configuration", "renderer", NULL))  // old version.
 	{
@@ -64,6 +63,7 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cUserBatteryIconName = CD_CONFIG_GET_STRING ("Configuration", "battery icon");
 	myConfig.cUserChargeIconName = CD_CONFIG_GET_STRING ("Configuration", "charge icon");
 	myConfig.cEmblemIconName = CD_CONFIG_GET_STRING ("Configuration", "emblem icon");
+	myConfig.bHideNotOnBattery = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "hide not on battery", FALSE);
 	
 	
 	GString *sKeyName = g_string_new ("");
@@ -74,8 +74,6 @@ CD_APPLET_GET_CONFIG_BEGIN
 	}
 	g_string_free (sKeyName, TRUE);
 	
-	myConfig.bUseApprox = CD_CONFIG_GET_BOOLEAN ("Configuration", "use approx");
-	
 	myConfig.fLastDischargeMeanRate = CD_CONFIG_GET_DOUBLE ("Configuration", "discharge rate");
 	myConfig.fLastChargeMeanRate = CD_CONFIG_GET_DOUBLE ("Configuration", "charge rate");
 CD_APPLET_GET_CONFIG_END
@@ -105,6 +103,10 @@ CD_APPLET_RESET_DATA_BEGIN
 	cairo_surface_destroy (myData.pSurfaceCharge);
 	
 	g_free (myData.cBatteryStateFilePath);
+
+	// g_free (myData.cTechnology); // can't be freed
+	g_free (myData.cVendor);
+	g_free (myData.cModel);
 	
 	cairo_dock_free_emblem (myData.pEmblem);
 	
