@@ -93,7 +93,7 @@ CD_APPLET_ON_CLICK_BEGIN
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)  // clic sur une des icones de la liste.
 	{
-		if (CD_APPLET_CLICKED_ICON->iType == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->iVolumeID)  // clic sur un point de montage.
+		if (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->iVolumeID)  // clic sur un point de montage.
 		{
 			gboolean bIsMounted = FALSE;
 			gchar *cActivationURI = cairo_dock_fm_is_mounted (CD_APPLET_CLICKED_ICON->cBaseURI, &bIsMounted);
@@ -107,7 +107,7 @@ CD_APPLET_ON_CLICK_BEGIN
 				cairo_dock_fm_mount_full (CD_APPLET_CLICKED_ICON->cBaseURI, CD_APPLET_CLICKED_ICON->iVolumeID, (CairoDockFMMountCallback) _open_on_mount, myApplet);
 			}
 		}
-		else if (CD_APPLET_CLICKED_ICON->iType == CD_BOOKMARK_GROUP)  // clic sur un signet, il peut etre place sur un volume non monte.
+		else if (CD_APPLET_CLICKED_ICON->iGroup == CD_BOOKMARK_GROUP)  // clic sur un signet, il peut etre place sur un volume non monte.
 		{
 			GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
 			CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
@@ -124,14 +124,14 @@ CD_APPLET_ON_CLICK_BEGIN
 			{
 				str = strchr (str, '/');
 			}
-			g_print ("bookmark '%s' on '%s'\n", CD_APPLET_CLICKED_ICON->cCommand, cVolumeUri);
+			//g_print ("bookmark '%s' on '%s'\n", CD_APPLET_CLICKED_ICON->cCommand, cVolumeUri);
 			gboolean bIsMounted = FALSE;
 			gchar *cActivationURI = cairo_dock_fm_is_mounted (CD_APPLET_CLICKED_ICON->cBaseURI, &bIsMounted);
 			g_free (cActivationURI);
 			* 
 			if (!bIsMounted)
 			{
-				g_print (" volume not mounted\n");
+				//g_print (" volume not mounted\n");
 				cairo_dock_fm_mount_full (cVolumeUri, 1, (CairoDockFMMountCallback) _open_on_mount, myApplet);
 			}
 			else
@@ -173,7 +173,7 @@ CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 	{
 		cairo_dock_fm_launch_uri (g_getenv ("HOME"));
 	}
-	else if (CD_APPLET_CLICKED_ICON != NULL && (CD_APPLET_CLICKED_ICON->iType == CD_DRIVE_GROUP || CD_APPLET_CLICKED_ICON->iVolumeID > 0))  // clic sur une icone du sous-dock ou du desklet, et de type 'point de montage'.
+	else if (CD_APPLET_CLICKED_ICON != NULL && (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP || CD_APPLET_CLICKED_ICON->iVolumeID > 0))  // clic sur une icone du sous-dock ou du desklet, et de type 'point de montage'.
 	{
 		_mount_unmount (CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER, myApplet);
 	}
@@ -232,6 +232,10 @@ static void _cd_shortcuts_show_disk_info (GtkMenuItem *menu_item, gpointer *data
 	g_free (cInfo);
 	CD_APPLET_LEAVE ();
 }
+static void _open_home_dir (GtkMenuItem *menu_item, gpointer data)
+{
+	cairo_dock_fm_launch_uri (g_getenv ("HOME"));
+}
 CD_APPLET_ON_BUILD_MENU_BEGIN
 	static gpointer *data = NULL;
 	if (data == NULL)
@@ -243,17 +247,20 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	if (CD_APPLET_CLICKED_ICON == myIcon)  // clic sur l'icone principale (mode dock donc).
 	{
 		GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
+		gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Open Home directory"), D_("middle-click"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_OPEN, _open_home_dir, CD_APPLET_MY_MENU);
+		g_free (cLabel);
 		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)  // clic sur un item.
 	{
-		if (CD_APPLET_CLICKED_ICON->iType == CD_BOOKMARK_GROUP)  // clic sur un signet.
+		if (CD_APPLET_CLICKED_ICON->iGroup == CD_BOOKMARK_GROUP)  // clic sur un signet.
 		{
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Rename this bookmark"),  GTK_STOCK_SAVE_AS, _cd_shortcuts_rename_bookmark, CD_APPLET_MY_MENU, data);
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Remove this bookmark"), GTK_STOCK_REMOVE, _cd_shortcuts_remove_bookmark, CD_APPLET_MY_MENU, CD_APPLET_CLICKED_ICON->cBaseURI);
 			CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
 		}
-		else if (CD_APPLET_CLICKED_ICON->iType == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->cBaseURI != NULL)  // clic sur un volume.
+		else if (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->cBaseURI != NULL)  // clic sur un volume.
 		{
 			if (cairo_dock_fm_can_eject (CD_APPLET_CLICKED_ICON->cBaseURI))
 				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Eject"), GTK_STOCK_DISCONNECT, _cd_shortcuts_eject, CD_APPLET_MY_MENU, data);
@@ -261,7 +268,9 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 			gboolean bIsMounted = FALSE;
 			gchar *cURI = cairo_dock_fm_is_mounted (CD_APPLET_CLICKED_ICON->cBaseURI, &bIsMounted);
 			g_free (cURI);
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (bIsMounted ? D_("Unmount (middle-click)") : D_("Mount (middle-click)"), GTK_STOCK_DISCONNECT, _cd_shortcuts_unmount, CD_APPLET_MY_MENU, data);
+			gchar *cLabel = g_strdup_printf ("%s (%s)", bIsMounted ? D_("Unmount") : D_("Mount"), D_("middle-click"));
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_DISCONNECT, _cd_shortcuts_unmount, CD_APPLET_MY_MENU, data);
+			g_free (cLabel);
 			
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Get disk info"), GTK_STOCK_PROPERTIES, _cd_shortcuts_show_disk_info, CD_APPLET_MY_MENU, data);
 		}
