@@ -44,15 +44,19 @@ static inline void _launch_item (Icon *pIcon, CairoDockModuleInstance *myApplet)
 CD_APPLET_ON_CLICK_BEGIN
 	if (CD_APPLET_CLICKED_ICON == myIcon)
 	{
-		if (CD_APPLET_MY_ICONS_LIST == NULL)
+		if (CD_APPLET_MY_ICONS_LIST == NULL)  // empty sub-dock or desklet.
 		{
 			cairo_dock_remove_dialog_if_any (myIcon);
 			cairo_dock_show_temporary_dialog_with_icon (D_("No items in the stack.\nYou can add files, URL, and even a piece of text by dragging them onto the icon."), myIcon, myContainer, 8000., "same icon");
 		}
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);  // on laisse passer la notification (pour ouvrir le sous-dock au clic).
+		else
+		{
+			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);  // on laisse passer la notification (pour ouvrir le sous-dock au clic).
+		}
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)
 	{
+		cd_debug ("_launch_item");
 		_launch_item (CD_APPLET_CLICKED_ICON, myApplet);  // on intercepte la notification.
 	}
 	else
@@ -175,10 +179,13 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	{
 		// Main Menu
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Open (click)"), GTK_STOCK_EXECUTE, _cd_stack_open_item, CD_APPLET_MY_MENU, data);
-		if (CD_APPLET_CLICKED_ICON->iVolumeID == 1)
+		gchar *cContent = CD_APPLET_CLICKED_ICON->cCommand;
+		if (strncmp (cContent, "file://", 7) == 0)
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Open parent folder"), GTK_STOCK_OPEN, _cd_stack_open_item_folder, CD_APPLET_MY_MENU, data);
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Copy (middle click)"), GTK_STOCK_COPY, _cd_stack_copy_content, CD_APPLET_MY_MENU, data);
+		gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Copy"), D_("middle-click"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_COPY, _cd_stack_copy_content, CD_APPLET_MY_MENU, data);
+		g_free (cLabel);
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Cut"), GTK_STOCK_CUT, _cd_stack_cut_item, CD_APPLET_MY_MENU, data);
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
@@ -204,3 +211,60 @@ CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 		_cd_stack_copy_content (NULL, data);
 	}
 CD_APPLET_ON_MIDDLE_CLICK_END
+
+
+gboolean cd_stack_on_drop_data (gpointer data, const gchar *cReceivedData, Icon *icon, double fOrder, CairoContainer *pContainer)
+{
+	//g_print ("Stack received '%s'\n", cReceivedData);
+	
+	// if we dropped on an icon, let pass the notif to it.
+	if (icon != NULL || fOrder == CAIRO_DOCK_LAST_ORDER)  // drop on an icon or outside of icons.
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	
+	// if it's a .desktop, let pass to the core (it will create the associated launcher).
+	if (g_str_has_suffix (cReceivedData, ".desktop"))
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	
+	// if it's not a file or an URL, let pass it.
+	gchar *cPath = NULL;
+	if (strncmp (cReceivedData, "file://", 7) == 0)  // it's a file.
+	{
+		cPath = g_filename_from_uri (cReceivedData, NULL, NULL);
+		if (!g_file_test (cPath, G_FILE_TEST_EXISTS)
+		|| g_file_test (cPath, G_FILE_TEST_IS_DIR))  // if the path doesn't exist, or is a folder, skip it (folders are handled by the 'Folders' applet).
+		{
+			g_free (cPath);
+			return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		}
+	}
+	else if (strncmp (cReceivedData, "http://", 7) != 0
+	&& strncmp (cReceivedData, "https://", 8) != 0)  // it's neither a file nor an URL.
+	{
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	}
+	
+	// grab the first instance of the Stack applet (launch it if necessary)
+	CairoDockModule *pModule = cairo_dock_find_module_from_name ("stack");
+	g_return_val_if_fail (pModule != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	
+	if (pModule->pInstancesList == NULL)  // no stack yet
+	{
+		cairo_dock_activate_module_and_load ("stack");
+		g_return_val_if_fail (pModule->pInstancesList != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	}
+	
+	// add the item to the instance.
+	CairoDockModuleInstance *myApplet = pModule->pInstancesList->data;
+	cd_stack_create_and_load_item (myApplet, cReceivedData);
+	
+	cairo_dock_show_temporary_dialog_with_icon (
+		cPath != NULL ?
+		D_("The file has been added to the stack."):
+		D_("The URL has been added to the stack."),
+		myIcon, myContainer,
+		5000,
+		"same icon");
+	
+	g_free (cPath);
+	return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
+}
