@@ -29,7 +29,7 @@
 #include "applet-init.h"
 
 
-CD_APPLET_DEFINITION (N_("switcher"),
+CD_APPLET_DEFINE_BEGIN (N_("switcher"),
 	2, 0, 9,
 	CAIRO_DOCK_CATEGORY_APPLET_DESKTOP,
 	N_("This applet allows you to interact with your workspaces :\n"
@@ -40,9 +40,13 @@ CD_APPLET_DEFINITION (N_("switcher"),
 	" - list all windows on each workspace ((middle-click or in the menu)\n"
 	"It has 2 modes : compact (on 1 icon) and expanded (with a sub-dock)."),
 	"Cchumi &amp; Fabounet")
+	CD_APPLET_DEFINE_COMMON_APPLET_INTERFACE
+	CD_APPLET_ALLOW_EMPTY_TITLE
+CD_APPLET_DEFINE_END
 
 
 CD_APPLET_INIT_BEGIN
+	//\_______________ Rregister the notifications we'll need
 	CD_APPLET_SET_STATIC_ICON;
 	CD_APPLET_REGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
@@ -64,13 +68,13 @@ CD_APPLET_INIT_BEGIN
 		NOTIFICATION_WINDOW_ACTIVATED,
 		(CairoDockNotificationFunc) on_change_active_window,
 		CAIRO_DOCK_RUN_AFTER, myApplet);
-	if (myConfig.bCompactView)
+	if (myConfig.bCompactView)  // in this mode we need to monitor the cursor
 	{
 		cairo_dock_register_notification_on_object (myContainer,
 			NOTIFICATION_MOUSE_MOVED,
 			(CairoDockNotificationFunc) on_mouse_moved,
 			CAIRO_DOCK_RUN_AFTER, myApplet);
-		if (myDesklet)
+		if (myDesklet)  // in this mode we draw the name of the pointed desktop
 		{
 			cairo_dock_register_notification_on_object (myContainer,
 				NOTIFICATION_RENDER_DESKLET,
@@ -87,33 +91,27 @@ CD_APPLET_INIT_BEGIN
 		}
 	}
 	
-	cd_switcher_update_from_screen_geometry ();
-	
-	//\___________________ On affiche le numero du bureau courant.
-	if (myConfig.bDisplayNumDesk)
-	{
-		int iIndex = cd_switcher_compute_index (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY);
-		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%d", iIndex+1);
-	}
-	
-	//\___________________ Dans le cas ou l'applet demarre au chargement de la session, le nombre de bureaux peut etre incorrect.
-	if (cairo_dock_is_loading ())
-		myData.iSidAutoRefresh = g_timeout_add_seconds (2, (GSourceFunc) cd_switcher_refresh_desktop_values, myApplet);
+	//\___________________ load the desktops with a delay (because it's quite heavy and because the desktop may not be up-to-date at the very beginning of the session).
+	if (myDesklet)
+		CD_APPLET_SET_DESKLET_RENDERER ("Simple");
+	cd_switcher_trigger_update_from_screen_geometry (FALSE);  // FALSE = delayed
 CD_APPLET_INIT_END
 
 
 CD_APPLET_STOP_BEGIN
-	//\_______________ On se desabonne de nos notifications.
+	//\_______________ Discard the pending drawings.
 	if (myData.iSidRedrawMainIconIdle != 0)
 	{
 		g_source_remove (myData.iSidRedrawMainIconIdle);
 	}
-	if (myData.iSidAutoRefresh != 0)
+	if (myData.iSidUpdateIdle != 0)
 	{
-		g_source_remove (myData.iSidAutoRefresh);
+		g_source_remove (myData.iSidUpdateIdle);
 	}
-	if (myData.iSidPainIcons != 0)
-		g_source_remove (myData.iSidPainIcons);
+	///if (myData.iSidPainIcons != 0)
+	///	g_source_remove (myData.iSidPainIcons);
+	
+	//\_______________ Unregister notifications
 	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
 	CD_APPLET_UNREGISTER_FOR_MIDDLE_CLICK_EVENT;
@@ -152,9 +150,13 @@ CD_APPLET_RELOAD_BEGIN
 		myData.iSidRedrawMainIconIdle = 0;
 	}
 	
-	cd_switcher_compute_nb_lines_and_columns ();
-	
-	cd_switcher_compute_desktop_coordinates (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY, &myData.switcher.iCurrentLine, &myData.switcher.iCurrentColumn);
+	// if our size has changed, re-compute the grid.
+	if (myData.iSidUpdateIdle == 0)
+	{
+		cd_switcher_compute_nb_lines_and_columns ();
+		
+		cd_switcher_compute_desktop_coordinates (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY, &myData.switcher.iCurrentLine, &myData.switcher.iCurrentColumn);
+	}
 	
 	if (CD_APPLET_MY_CONFIG_CHANGED)
 	{
@@ -170,6 +172,7 @@ CD_APPLET_RELOAD_BEGIN
 			}
 		}
 		
+		// in case our container or our mode has changed (desklet <-> dock, compact <-> expanded), register to the needed notifications.
 		cairo_dock_remove_notification_func_on_object (CD_APPLET_MY_OLD_CONTAINER,
 			NOTIFICATION_MOUSE_MOVED,
 			(CairoDockNotificationFunc) on_mouse_moved, myApplet);
@@ -206,48 +209,20 @@ CD_APPLET_RELOAD_BEGIN
 			}
 		}
 		
-		//~ if (CD_APPLET_MY_OLD_CONTAINER != myContainer || ! myConfig.bCompactView)
-		//~ {
-			//~ cairo_dock_remove_notification_func_on_object (CD_APPLET_MY_OLD_CONTAINER,
-				//~ NOTIFICATION_MOUSE_MOVED,
-				//~ (CairoDockNotificationFunc) on_mouse_moved, myApplet);
-			//~ cairo_dock_remove_notification_func_on_object (CD_APPLET_MY_OLD_CONTAINER,
-				//~ NOTIFICATION_RENDER_DESKLET,
-				//~ (CairoDockNotificationFunc) on_render_desklet, myApplet);
-			//~ if (myConfig.bCompactView)
-			//~ {
-				//~ cairo_dock_register_notification_on_object (myContainer,
-					//~ NOTIFICATION_MOUSE_MOVED,
-					//~ (CairoDockNotificationFunc) on_mouse_moved,
-					//~ CAIRO_DOCK_RUN_AFTER, myApplet);
-				//~ if (myDesklet)
-				//~ {
-					//~ cairo_dock_register_notification_on_object (myDesklet,
-						//~ NOTIFICATION_RENDER_DESKLET,
-						//~ (CairoDockNotificationFunc) on_render_desklet,
-						//~ CAIRO_DOCK_RUN_AFTER, myApplet);
-					//~ cairo_dock_register_notification_on_object (myDesklet,
-						//~ NOTIFICATION_UPDATE_DESKLET,
-						//~ (CairoDockNotificationFunc) on_update_desklet,
-						//~ CAIRO_DOCK_RUN_AFTER, myApplet);
-					//~ cairo_dock_register_notification_on_object (myDesklet,
-						//~ NOTIFICATION_LEAVE_DESKLET,
-						//~ (CairoDockNotificationFunc) on_leave_desklet,
-						//~ CAIRO_DOCK_RUN_AFTER, myApplet);
-				//~ }
-			//~ }
-		//~ }
-		if (myConfig.bDisplayNumDesk)
+		if (myData.iSidUpdateIdle == 0)
 		{
-			int iIndex = cd_switcher_compute_index (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY);
-			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%d", iIndex+1);
+			if (myConfig.bDisplayNumDesk)
+			{
+				int iIndex = cd_switcher_compute_index (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY);
+				CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%d", iIndex+1);
+			}
+			else
+				CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (NULL);
+			
+			cd_switcher_load_icons ();
 		}
-		else
-			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (NULL);
-		
-		cd_switcher_load_icons ();
 	}
-	else
+	else if (myData.iSidUpdateIdle == 0)  // if only our size has changed, re-load the images.
 	{
 		if (myConfig.bMapWallpaper)  // on recharge le wallpaper a la taille de l'applet.
 		{
@@ -255,9 +230,11 @@ CD_APPLET_RELOAD_BEGIN
 		}
 		if (myData.pDesktopBgMapSurface == NULL)
 			cd_switcher_load_default_map_surface ();
-		if (! myConfig.bCompactView)
-			cd_switcher_trigger_paint_icons ();
+		///if (! myConfig.bCompactView)
+		///	cd_switcher_trigger_paint_icons ();
 	}
 	
-	cd_switcher_draw_main_icon ();
+	// redraw.
+	if (myData.iSidUpdateIdle == 0)
+		cd_switcher_draw_main_icon ();
 CD_APPLET_RELOAD_END
