@@ -50,6 +50,7 @@ CairoDialog *cd_terminal_build_dialog (void)
 	memset (&attr, 0, sizeof (CairoDialogAttribute));
 	attr.cText = D_ ("Terminal");
 	attr.pInteractiveWidget = myData.tab;
+	attr.bHideOnClick = TRUE;  // keep the dialog alive on click (hide it).
 	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
 }
 
@@ -289,25 +290,52 @@ void term_apply_settings (void)
 	}
 }
 
-static void on_terminal_child_exited(VteTerminal *vteterminal,
+static void on_terminal_child_exited(VteTerminal *vterm,
                                      gpointer t)
 {
-	gint p = gtk_notebook_page_num(GTK_NOTEBOOK(myData.tab), GTK_WIDGET(vteterminal));
+	gint p = gtk_notebook_page_num(GTK_NOTEBOOK(myData.tab), GTK_WIDGET(vterm));
 	gint sz = gtk_notebook_get_n_pages(GTK_NOTEBOOK(myData.tab));
 
 	if (sz > 1)
 		gtk_notebook_remove_page(GTK_NOTEBOOK(myData.tab), p);
 	else {
 		// \r needed to return to the beginning of the line
-		vte_terminal_feed(VTE_TERMINAL(vteterminal), "Shell exited. Another one is launching...\r\n\n", -1);
-		vte_terminal_fork_command(VTE_TERMINAL(vteterminal),
-			NULL,
-			NULL,
-			NULL,
-			"~/",
-			FALSE,
-			FALSE,
-			FALSE);
+		vte_terminal_feed(VTE_TERMINAL(vterm), "Shell exited. Another one is launching...\r\n\n", -1);
+		
+		pid_t pid; 
+		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
+			#if VTE_CHECK_VERSION(0,26,0)
+			const gchar *argv[] = {g_getenv ("SHELL"), NULL};
+			vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
+				VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
+				"~/",
+				(gchar**)argv,  // argv
+				NULL,  // envv
+				0,  // GSpawnFlags spawn_flags
+				NULL,  // GSpawnChildSetupFunc child_setup
+				NULL,  // gpointer child_setup_data
+				&pid,
+				NULL);
+			#else
+			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+				NULL,
+				NULL,
+				NULL,
+				"~/",
+				FALSE,
+				FALSE,
+				FALSE);
+			#endif
+		#else
+			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+				NULL,
+				NULL,
+				NULL,
+				"~/",
+				FALSE,
+				FALSE,
+				FALSE);
+		#endif
 		if (myData.dialog)
 			cairo_dock_hide_dialog (myData.dialog);
 		else if (myDesklet && myConfig.shortcut)
@@ -357,12 +385,18 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 	{
 		menu_item = gtk_image_menu_item_new_with_label (D_("Copy"));
 		image = gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
 		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_copy), vterm);
 		
 		menu_item = gtk_image_menu_item_new_with_label (D_("Paste"));
 		image = gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
 		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_paste), vterm);
@@ -373,24 +407,36 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 
   menu_item = gtk_image_menu_item_new_with_label (D_("New Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_new_tab), vterm);
   
   menu_item = gtk_image_menu_item_new_with_label (D_("Rename this Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_rename_tab), vterm);
 
   menu_item = gtk_image_menu_item_new_with_label (D_("Change this Tab's colour"));
   image = gtk_image_new_from_stock (GTK_STOCK_COLOR_PICKER, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_change_tab_color), vterm);
 
   menu_item = gtk_image_menu_item_new_with_label (D_("Close this Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
+#endif
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_close_tab), vterm);
@@ -417,7 +463,7 @@ static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *ev
 	}
 	return FALSE;
 }
-static void applet_on_terminal_eof(VteTerminal *vteterminal,
+static void applet_on_terminal_eof(VteTerminal *vterm,
                                    gpointer     user_data)
 {
 	cd_debug ("youkata EOF");
@@ -509,14 +555,40 @@ void terminal_new_tab(void)
 	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
 	#endif
 	vte_terminal_set_emulation(VTE_TERMINAL(vterm), "xterm");
-	vte_terminal_fork_command(VTE_TERMINAL(vterm),
-		NULL,
-		NULL,
-		NULL,
-		"~/",
-		FALSE,
-		FALSE,
-		FALSE);
+	pid_t pid; 
+	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
+		#if VTE_CHECK_VERSION(0,26,0)
+		const gchar *argv[] = {g_getenv ("SHELL"), NULL};
+		vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
+			VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
+			"~/",
+			(gchar**)argv,  // argv
+			NULL,  // envv
+			0,  // GSpawnFlags spawn_flags
+			NULL,  // GSpawnChildSetupFunc child_setup
+			NULL,  // gpointer child_setup_data
+			&pid,
+			NULL);
+		#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+		#endif
+	#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+	#endif
 	g_signal_connect (G_OBJECT (vterm), "child-exited",
 				G_CALLBACK (on_terminal_child_exited), NULL);
 	g_signal_connect (G_OBJECT (vterm), "button-release-event",
@@ -703,14 +775,14 @@ static gboolean on_button_press_tab (GtkWidget* pWidget,
 }
 
 
-static gboolean on_button_press_dialog (GtkWidget *widget,
+/**static gboolean on_button_press_dialog (GtkWidget *widget,
 	GdkEventButton *pButton,
 	CairoDialog *pDialog)
 {
 	cd_message ("hide the dialog when clicking on it");
 	cairo_dock_hide_dialog (pDialog);
 	return TRUE;
-}
+}*/
 void terminal_build_and_show_tab (void)
 {
 	//\_________________ On cree un notebook.
@@ -738,10 +810,10 @@ void terminal_build_and_show_tab (void)
 	if (myDock)
 	{
 		myData.dialog = cd_terminal_build_dialog ();
-		g_signal_connect (G_OBJECT (myData.dialog->container.pWidget),
+		/**g_signal_connect (G_OBJECT (myData.dialog->container.pWidget),
 			"button-press-event",
 			G_CALLBACK (on_button_press_dialog),
-			myData.dialog);  // on le cache quand on clique dessus.
+			myData.dialog);*/  // on le cache quand on clique dessus.
 		cd_terminal_grab_focus ();
 	}
 	else
